--[[
	RecipeKnown Database
	v0.28
	
	Revision: $Id: Database.lua 26 2012-09-05 23:51:49z Kjasi $
]]

local rk = _G.RecipeKnown
if (not rk) then
	print(RED_FONT_COLOR_CODE.."Unable to find RecipeKnown's Global."..FONT_COLOR_CODE_CLOSE)
	return
end
local L = rk.Localization
if (not L) then
	print(RED_FONT_COLOR_CODE.."Unable to find RecipeKnown's Localization data."..FONT_COLOR_CODE_CLOSE)
	return
end

rk.Database = {}
local db = rk.Database

-- Used to force conversion of items that are stubborn about coloring. Also used for items which have mis-matched names.
db.ItemEnch = {
	-- Recipe ItemID = EnchantID
	-- Sorted by Job, then by EnchantID

	-- Alchemy
	[2555] = 2335,		-- Swiftness Potion
	[3832] = 3453,		-- Elixir of Detect Lesser Invisibiliy
	[5640] = 6617,		-- Rage Potion
	[9294] = 11458,		-- Wildvine Potion
	[9304] = 11479,		-- Transmute: Iron to Gold
	[9305] = 11480,		-- Transmute: Mithril to Truesilver
	[12958] = 17187,	-- Transmute: Arcanite
	[13482] = 17559,	-- Transmute: Air to Fire
	[13483] = 17560,	-- Transmute: Fire to Earth
	[13484] = 17561,	-- Transmute: Earth to Water
	[13485] = 17562,	-- Transmute: Water to Air
	[13486] = 17563,	-- Transmute: Undeath to Water
	[13487] = 17564,	-- Transmute: Water to Undeath
	[13488] = 17565,	-- Transmute: Life to Earth
	[13489] = 17566,	-- Transmute: Earth to Life
	[20761] = 25146,	-- Transmute: Elemental Fire
	[22913] = 28564,	-- Haste Potion (BoE version)
	[22915] = 28566,	-- Transmute: Primal Air to Fire
	[22916] = 28567,	-- Transmute: Primal Earth to Water
	[22917] = 28568,	-- Transmute: Primal Fire to Earth (Horde Version)
	[22918] = 28569,	-- Transmute: Primal Water to Air
	[23574] = 29688,	-- Transmute: Primal Might
	[25869] = 32765,	-- Transmute: Earthstorm Diamond
	[25870] = 32766,	-- Transmute: Skyfire Diamond (Alliance Edition)
	[29232] = 32766,	-- Transmute: Skyfire Diamond (Horde Edition)
	[30443] = 28568,	-- Transmute: Primal Fire to Earth (Alliance Version)
	[35295] = 28564,	-- Haste Potion (Kael'thas Sunstrider Edition)

	-- Blacksmithing
	[3609] = 3321,		-- Copper Chain Vest
	[10713] = 11454,	-- Inlaid Mithril Cylinder
	[25846] = 32656,	-- Adamantite Rod

	-- Cooking
	[6039] = 7213,		-- Giant Clam Scorcho
	[17062] = 20916,	-- Mithril Head Trout
	[17200] = 21143,	-- Gingerbread Cookie
	[21025] = 25659,	-- Dirge's Kickin' Chimaerok Chops
	[27688] = 33284,	-- Ravager Dog
	[65409] = 88025,	-- Lavascale Minestrone

	-- Enchanting
	[11081] = 13464,	-- Enchant Shield - Lesser Protection
	[16223] = 20029,	-- Enchant Weapon - Icy Chill
	[16248] = 20033,	-- Enchant Weapon - Unholy
	[16255] = 20035,	-- Enchant 2H Weapon - Major Spirit
	[19447] = 23802,	-- Enchant Bracer - Healing Power
	[22531] = 27911,	-- Enchant Bracer - Superior Healing (Alliance Version)
	[24000] = 27911,	-- Enchant Bracer - Superior Healing (Horde Version)
	[44498] = 60767,	-- Enchant Bracers - Superior Spellpower
	[44944] = 62256,	-- Enchant Bracers - Major Stamina
	[67312] = 93843,	-- Magic Lamp

	-- Engineering
	[4408] = 3928,		-- Mechanical Squirrel
	[17720]	= 21940,	-- Snowmaster 9000
	[18654] = 23096,	-- Gnomish Alarm-O-Bot
	[35186] = 46111,	-- Annihilator Holo-Gogs

	-- Inscription
	[46108] = 64051,	-- Rituals of the New Moon
	[50166] = 71101,	-- Glyph of Eternal Water
	[50167] = 71015,	-- Glyph of Rapid Rejuvenation
	[50168] = 71102,	-- Glyph of Quick Decay

	-- Leatherworking
	[4300] = 3777,		-- Guardian Leather Bracers
	[7288] = 9064,		-- Rugged Leather Pants
	[14635] = 3778,		-- Gem-studded Leather Belt
	[15724] = 19048,	-- Heavy Scorpid Bracers
	[15728] = 19052,	-- Wicked Leather Bracers
	[15732] = 19059,	-- Volcanic Leggings
	[15738] = 19064,	-- Heavy Scorpid Gauntlets
	[15748] = 19075,	-- Heavy Scorpid Leggings
	[15752] = 19078,	-- Living Leggings
	[15762] = 19088,	-- Heavy Scorpid Helm
	[17722] = 21943,	-- Gloves of the Greatfather
	[18518] = 22927,	-- Hide of the Wild
	[29214] = 32499,	-- Felstalker Bracer
	[29720] = 35555,	-- Clefthide Leg Armor
	[44534] = 60732,	-- Swiftarrow Gauntlets

	-- Jewelcrafting
	[21941] = 26875,	-- Figurine - Black Pearl Panther
	[35202] = 46126,	-- Amulet of Flowing Life
	[41708] = 55396,	-- Insightful Earthsiege Diamond
	[41782] = 54004,	-- Shining Forest Emerald
	[41785] = 53980,	-- Glinting Twilight Opal
	[41788] = 55405,	-- Beaming Earthsiege Diamond
	[42315] = 56089,	-- Thick Dragon's Eye
	[42650] = 56498,	-- Titanium Spellshock Ring

	-- Tailoring
	[5771] = 6686,		-- Red Linen Bag
	[14630] = 3857,		-- Enchanter's Cowl
	[21722] = 26403,	-- Festival Dress
	[21723]	= 26407,	-- Festive Red Pant Suit

	-- Unsorted
	-- Gathered by RK's Database Generator
	[15752] = 19078,
	[23816] = 30348,
	[20758] = 25124,
	[30483] = 36686,
	[17724] = 21945,
	[41581] = 53954,
	[42651] = 56499,
	[12231] = 15861,
	[12239] = 15906,
	[21916] = 26760,
	[21948] = 26897,
	[46931] = 66504,
	[46947] = 66566,
	[30156] = 36210,
	[13309] = 3939,
	[5642] = 6624,
	[44472] = 47898,
	[44488] = 47899,
	[44536] = 60735,
	[27689] = 33285,
	[10311] = 12064,
	[10315] = 12078,
	[9301] = 11476,
	[3611] = 3334,
	[41726] = 53974,
	[6716] = 8339,
	[46916] = 66446,
	[13940] = 18239,
	[13948] = 18246,
	[14467] = 18404,
	[14471] = 18408,
	[44489] = 60692,
	[23817] = 30349,
	[14483] = 18419,
	[44537] = 60737,
	[17709] = 21923,
	[17725] = 21931,
	[34413] = 45022,
	[16048] = 19796,
	[8387] = 10531,
	[21358] = 26085,
	[20855] = 25323,
	[22907] = 28555,
	[21893] = 26749,
	[21901] = 26778,
	[21917] = 26762,
	[7289] = 9070,
	[21949] = 26900,
	[6271] = 7629,
	[6275] = 7643,
	[20975] = 25619,
	[5772] = 6688,
	[44490] = 60763,
	[5786] = 6702,
	[27690] = 33286,
	[41568] = 53921,
	[20576] = 24940,
	[35564] = 46684,
	[11098] = 13522,
	[6325] = 7751,
	[3678] = 3370,
	[3679] = 3371,
	[3680] = 3372,
	[10607] = 12617,
	[4293] = 3762,
	[18652] = 23077,
	[15733] = 19060,
	[15737] = 19063,
	[15741] = 19067,
	[38327] = 50644,
	[6349] = 7793,
	[23810] = 30337,
	[20752] = 25125,
	[15761] = 19087,
	[11166] = 13698,
	[6369] = 7828,
	[12228] = 15855,
	[12232] = 15863,
	[6892] = 8607,
	[12240] = 15910,
	[41697] = 53998,
	[4345] = 3847,
	[4349] = 3851,
	[21942] = 26878,
	[44859] = 62051,
	[4355] = 3862,
	[6401] = 3870,
	[2697] = 2542,
	[38328] = 50647,
	[2699] = 2547,
	[2700] = 2548,
	[2701] = 2549,
	[44524] = 60720,
	[12839] = 56478,
	[27699] = 33295,
	[7453] = 9208,
	[10300] = 12056,
	[10312] = 12066,
	[18046] = 22480,
	[10320] = 12084,
	[28282] = 34009,
	[35566] = 46688,
	[4409] = 3933,
	[13941] = 18241,
	[13945] = 18243,
	[13949] = 18247,
	[6475] = 7954,
	[23803] = 30316,
	[14476] = 18412,
	[20753] = 25126,
	[5972] = 7133,
	[44541] = 60748,
	[13478] = 17554,
	[13490] = 17570,
	[16053] = 19825,
	[8400] = 10564,
	[21895] = 26751,
	[21911] = 26755,
	[21919] = 26763,
	[41747] = 53963,
	[44861] = 62045,
	[46921] = 66451,
	[46937] = 66556,
	[7561] = 9273,
	[18949] = 23399,
	[37340] = 44588,
	[37915] = 49677,
	[27692] = 33288,
	[27700] = 33296,
	[6056] = 7258,
	[25720] = 32455,
	[16221] = 20026,
	[44862] = 62044,
	[7613] = 3772,
	[15734] = 19061,
	[16249] = 20036,
	[15746] = 19073,
	[10644] = 11456,
	[17201] = 21144,
	[22902] = 28549,
	[21896] = 26773,
	[41701] = 53967,
	[10728] = 3873,
	[4609] = 4094,
	[46939] = 66558,
	[6663] = 8240,
	[44496] = 59619,
	[18487] = 22902,
	[18519] = 22928,
	[22647] = 28267,
	[45774] = 63924,
	[41718] = 53946,
	[47022] = 66586,
	[46950] = 66569,
	[46948] = 66567,
	[3681] = 3373,
	[46924] = 66497,
	[18647] = 23066,
	[13942] = 18240,
	[13946] = 18244,
	[21737] = 26443,
	[46935] = 66554,
	[14469] = 18406,
	[23805] = 30318,
	[46934] = 66553,
	[46917] = 66447,
	[46919] = 66449,
	[15727] = 19051,
	[46897] = 66338,
	[11150] = 13612,
	[42138] = 53952,
	[21945] = 26887,
	[16046] = 19814,
	[13495] = 17575,
	[16054] = 19830,
	[41698] = 53997,
	[8397] = 10533,
	[8401] = 10568,
	[41705] = 55384,
	[21897] = 26774,
	[41703] = 53971,
	[41719] = 53948,
	[41687] = 53991,
	[41686] = 53984,
	[16220] = 20024,
	[7290] = 9072,
	[6270] = 7630,
	[42653] = 56501,
	[6274] = 7639,
	[42649] = 56497,
	[16767] = 20626,
	[20971] = 25612,
	[2889] = 2795,
	[21918] = 26761,
	[34262] = 44953,
	[44858] = 62049,
	[43318] = 58148,
	[44530] = 60728,
	[37349] = 44631,
	[5787] = 6703,
	[5789] = 6705,
	[42298] = 56049,
	[2598] = 2389,
	[41576] = 53830,
	[44495] = 59625,
	[5974] = 7153,
	[21099] = 25704,
	[44491] = 47901,
	[44494] = 44576,
	[728] = 2543,
	[44487] = 60714,
	[32381] = 39895,
	[10325] = 12091,
	[6326] = 7752,
	[6328] = 7753,
	[44483] = 60691,
	[41784] = 53962,
	[42311] = 56086,
	[4292] = 3758,
	[4294] = 3767,
	[7362] = 9147,
	[21219] = 25954,
	[2409] = 2169,
	[15743] = 19070,
	[15747] = 19074,
	[11152] = 13620,
	[15755] = 19081,
	[18731] = 23190,
	[37347] = 44591,
	[18648] = 23068,
	[17722] = 21943,
	[15779] = 19104,
	[44471] = 47672,
	[6368] = 7827,
	[22307] = 27658,
	[42188] = 56011,
	[15739] = 19065,
	[12226] = 15935,
	[6342] = 7443,
	[7364] = 9149,
	[13491] = 17571,
	[41689] = 53983,
	[3683] = 3377,
	[4346] = 3844,
	[2407] = 2163,
	[9294] = 11458,
	[13288] = 4097,
	[46911] = 66441,
	[21892] = 26747,
	[21947] = 26896,
	[6329] = 7754,
	[14627] = 3869,
	[7114] = 3854,
	[47007] = 66574,
	[18656] = 23080,
	[44484] = 44575,
	[7363] = 9148,
	[5788] = 6704,
	[44532] = 60730,
	[45059] = 62948,
	[21547] = 26277,
	[41574] = 53869,
	[27695] = 33291,
	[16055] = 19831,
	[2406] = 2158,
	[41578] = 53949,
	[10302] = 12060,
	[3393] = 3172,
	[42648] = 56496,
	[10314] = 12075,
	[9296] = 11466,
	[42185] = 56006,
	[8399] = 10554,
	[5489] = 6419,
	[41722] = 53993,
	[4410] = 3940,
	[4412] = 3954,
	[4414] = 3960,
	[4416] = 3968,
	[6474] = 7953,
	[6476] = 7955,
	[13939] = 18238,
	[13943] = 18242,
	[13947] = 18245,
	[44533] = 60731,
	[24302] = 31442,
	[23799] = 30313,
	[44485] = 44625,
	[23815] = 30347,
	[14482] = 18418,
	[5973] = 7149,
	[14490] = 18434,
	[6377] = 7867,
	[16044] = 19793,
	[27694] = 33290,
	[27696] = 33292,
	[8395] = 10525,
	[41579] = 53961,
	[34319] = 44958,
	[8390] = 10562,
	[14526] = 18560,
	[8398] = 10542,
	[8402] = 10570,
	[14499] = 18445,
	[10317] = 12080,
	[41707] = 55407,
	[21915] = 26759,
	[4299] = 3773,
	[2698] = 2545,
	[21957] = 26915,
	[41787] = 55395,
	[22901] = 28546,
	[21738] = 26442,
	[16111] = 15915,
	[13499] = 17578,
	[16110] = 15933,
	[20973] = 25617,
	[7560] = 9269,
	[5485] = 6415,
	[44486] = 60707,
	[24316] = 31373,
	[4296] = 3769,
	[3610] = 3325,
	[3872] = 3507,
	[44510] = 50971,
	[41720] = 53957,
	[2601] = 2403,
	[3830] = 3450,
	[21943] = 26881,
	[21944] = 26882,
	[11163] = 13646,
	[27684] = 33279,
	[12836] = 64729,
	[3682] = 3376,
	[6057] = 7259,
	[18239] = 22711,
	[10602] = 12597,
	[21898] = 26775,
	[16243] = 20051,
	[41777] = 53976,
	[27697] = 33293,
	[14512] = 18456,
	[14639] = 3952,
	[2408] = 2164,
	[6344] = 7766,
	[10609] = 12624,
	[16218] = 20009,
	[6346] = 7776,
	[16251] = 20011,
	[7449] = 9195,
	[7087] = 8789,
	[16254] = 20032,
	[4624] = 4942,
	[4348] = 3868,
	[16224] = 20015,
	[9298] = 11472,
	[20856] = 25320,
	[14513] = 18457,
	[3734] = 3397,
	[10606] = 12616,
	[41780] = 53977,
	[22562] = 28016,
	[6272] = 7633,
	[22563] = 28019,
	[41786] = 55390,
	[21899] = 26776,
	[22729] = 28327,
	[15759] = 19085,
	[10604] = 12614,
	[11203] = 13841,
	[16049] = 19799,
	[13311] = 3969,
	[10603] = 12607,
	[23814] = 30344,
	[28271] = 33994,
	[25735] = 32495,
	[25736] = 32496,
	[25737] = 32497,
	[22909] = 28557,
	[5528] = 6501,
	[21548] = 26279,
	[6047] = 3503,
	[41564] = 53888,
	[6053] = 7255,
	[28271] = 33994,
	[42187] = 56009,
	[11101] = 13536,
	[16215] = 20020,
	[18658] = 23082,
	[16247] = 20030,
	[5578] = 2673,
	[44503] = 60867,
	[15760] = 19086,
	[44535] = 60734,
	[43018] = 45555,
	[43034] = 57440,
	[41565] = 53879,
	[18267] = 22761,
	[2553] = 3230,
	[20854] = 25339,
	[42172] = 55993,
	[41725] = 53965,
	[20974] = 25618,
	[47011] = 66577,
	[22539] = 27945,
	[22547] = 27960,
	[43019] = 45556,
	[43035] = 57441,
	[41566] = 53875,
	[9293] = 11453,
	[28272] = 33997,
	[25725] = 32461,
	[22683] = 28210,
	[41742] = 55393,
	[6712] = 8334,
	[10858] = 3494,
	[46900] = 66430,
	[38229] = 50194,
	[7742] = 3971,
	[6211] = 3188,
	[43020] = 45557,
	[43036] = 57442,
	[41567] = 53917,
	[16052] = 19819,
	[13501] = 17580,
	[41727] = 53960,
	[41743] = 55387,
	[46933] = 66506,
	[19442] = 23787,
	[5774] = 6693,
	[11038] = 13380,
	[43021] = 45558,
	[43037] = 57443,
	[27698] = 33294,
	[19027] = 23507,
	[25726] = 32482,
	[24209] = 31102,
	[41728] = 53955,
	[41744] = 55388,
	[46902] = 66432,
	[46918] = 66448,
	[15725] = 19049,
	[7361] = 9146,
	[44954] = 62350,
	[22772] = 28482,
	[44539] = 60746,
	[43022] = 45559,
	[44587] = 60999,
	[25910] = 32874,
	[41569] = 53933,
	[6375] = 7859,
	[11206] = 13882,
	[22900] = 28543,
	[21894] = 26750,
	[21902] = 26779,
	[4347] = 3849,
	[49953] = 70550,
	[46903] = 66433,
	[43023] = 45567,
	[7451] = 9202,
	[41570] = 53932,
	[24170] = 31072,
	[10316] = 12047,
	[28274] = 34003,
	[25735] = 32495,
	[41730] = 53986,
	[49954] = 70551,
	[4417] = 3972,
	[18661] = 23129,
	[22773] = 28481,
	[24314] = 31459,
	[23811] = 30341,
	[22310] = 27724,
	[41571] = 53924,
	[13494] = 17574,
	[5483] = 6413,
	[22909] = 28557,
	[49955] = 70552,
	[16113] = 10840,
	[18414] = 22866,
	[11039] = 13419,
	[43025] = 45571,
	[20075] = 24418,
	[7084] = 8793,
	[24195] = 31087,
	[7088] = 8802,
	[6068] = 3449,
	[41732] = 53990,
	[49956] = 70553,
	[46906] = 66436,
	[15726] = 19050,
	[22774] = 28480,
	[25848] = 32665,
	[44511] = 60645,
	[43505] = 58527,
	[34834] = 45695,
	[43026] = 45570,
	[41573] = 53929,
	[12229] = 15856,
	[12233] = 15865,
	[4597] = 4508,
	[41733] = 53981,
	[41781] = 54003,
	[21952] = 26906,
	[6661] = 8238,
	[5643] = 6618,
	[43506] = 58528,
	[43027] = 57433,
	[10301] = 12059,
	[23142] = 28918,
	[9295] = 11464,
	[9303] = 11459,
	[25737] = 32497,
	[24212] = 31105,
	[41734] = 53978,
	[46940] = 66559,
	[24292] = 31430,
	[47020] = 66584,
	[25849] = 32667,
	[20755] = 25128,
	[44545] = 60752,
	[43028] = 57434,
	[13479] = 17555,
	[41559] = 53857,
	[41575] = 53865,
	[16050] = 19815,
	[8389] = 10560,
	[22392] = 27837,
	[22911] = 28562,
	[41735] = 54014,
	[2881] = 2667,
	[41783] = 53966,
	[3394] = 3174,
	[46925] = 66498,
	[46941] = 66560,
	[33160] = 42593,
	[19446] = 23801,
	[37344] = 44524,
	[22552] = 27967,
	[44546] = 60754,
	[43029] = 57435,
	[54798] = 75597,
	[41560] = 53943,
	[42183] = 56004,
	[41736] = 54013,
	[10601] = 12587,
	[7360] = 3765,
	[12162] = 3492,
	[6348] = 7786,
	[23814] = 30344,
	[44531] = 60729,
	[44547] = 60755,
	[43030] = 57436,
	[29213] = 32498,
	[18517] = 22926,
	[41796] = 53970,
	[22308] = 27659,
	[41790] = 53951,
	[6347] = 7782,
	[11204] = 13846,
	[11208] = 13915,
	[29215] = 32500,
	[42184] = 56005,
	[6330] = 7755,
	[7091] = 8782,
	[41721] = 53988,
	[41737] = 54005,
	[3866] = 3493,
	[31877] = 39462,
	[4352] = 3860,
	[21954] = 26910,
	[46927] = 66500,
	[10323] = 12089,
	[11223] = 13931,
	[13308] = 3957,
	[24218] = 31111,
	[42178] = 55999,
	[3395] = 3175,
	[25736] = 32496,
	[6390] = 7892,
	[6391] = 7893,
	[22905] = 28553,
	[43033] = 57439,
	[47630] = 67082,
	[3608] = 3297,
	[7450] = 9197,
	[15763] = 19089,
	[41562] = 53877,
	[22312] = 27725,
	[5486] = 6416,
	[24217] = 31110,
	[15420] = 19062,
	[22536] = 27924,
	[10318] = 12081,
	[30833] = 37873,
	[25847] = 32667,
	[41706] = 55392,
	[12227] = 15853,
	[41738] = 54000,
	[14494] = 18439,
	[11205] = 13868,
	[49112] = 68253,
	[15729] = 19053,
	[46928] = 66501,
	[18649] = 23067,
	[20253] = 19068,
	[15758] = 19084,
	[43024] = 45568,
	[16252] = 20034,
	[20733] = 25082,
	[23807] = 30329,
	[19216] = 23664,
	[43017] = 57423,
	[27686] = 33277,
	[44549] = 60757,
	[43032] = 57438,
	[14634] = 3454,
	[43031] = 57437,
	[15770] = 19094,
	[41563] = 53884,
	[14514] = 18458,
	[8386] = 10520,
	[3736] = 3399,
	[5482] = 6412,
	[5484] = 6414,
	[19328] = 23705,
	[5488] = 6418,
	[2883] = 3295,
	[39152] = 45546,
	[20754] = 25127,
	[41739] = 54010,
	[19217] = 23665,
	[20732] = 25081,
	[7086] = 8797,
	[41740] = 53968,
	[46929] = 66502,
	[29719] = 35549,
	[21953] = 26909,
	[3735] = 3398,
	[41572] = 53919,
	[11207] = 13898,
	[41778] = 54023,
	[33165] = 42620,
	[22538] = 27927,
	[3682] = 3376,
	[3869] = 3500,
	[4353] = 3863,
	[44515] = 60703,
	[4354] = 3872,
	[44509] = 50970,
	[34872] = 45765,
	[7976] = 9939,
	[7992] = 9995,
	[43509] = 58523,
	[44519] = 60711,
	[3831] = 3451,
	[18418] = 22870,
	[13497] = 17577,
	[27685] = 33276,
	[20757] = 25130,
	[27687] = 33278,
	[13310] = 3979,
	[35500] = 46594,
	[17017] = 20848,
	[41704] = 55389,
	[10326] = 12093,
	[44543] = 60750,
	[41797] = 55401,
	[10321] = 12085,
	[19219] = 23666,
	[19444] = 23799,
	[33871] = 43758,
	[44492] = 59621,
	[49050] = 68067,
	[19448] = 23803,
	[44516] = 60704,
	[3873] = 3511,
	[19766] = 24093,
	[31674] = 38868,
	[31675] = 38867,
	[41799] = 55398,
	[46912] = 66442,
	[33873] = 43765,
	[44514] = 60702,
	[46910] = 66440,
	[43510] = 58525,
	[2882] = 3330,
	[44542] = 60749,
	[43508] = 58521,
	[44526] = 60723,
	[52023] = 72953,
	[43507] = 58512,
	[44520] = 60712,
	[44518] = 60706,
	[46930] = 66503,
	[44538] = 60743,
	[32070] = 39637,
	[46936] = 66555,
	[45201] = 26420,
	[23883] = 30551,
	[44548] = 60756,
	[17018] = 20849,
	[33925] = 43779,
	[44513] = 60697,
	[22565] = 28022,
	[5487] = 6417,
	[44517] = 60705,
	[46904] = 66434,
	[47010] = 66576,
	[46949] = 66568,
	[46922] = 66452,
	[46905] = 66435,
	[46938] = 66557,
	[41696] = 54009,
	[46909] = 66439,
	[41577] = 53945,
	[41690] = 53987,
	[46920] = 66450,
	[41582] = 53980,
	[42314] = 56055,
	[12683] = 16643,
	[4401] = 3928,
	[65409] = 88025,
	[12164] = 3498,
	[4350] = 3856,
	[21940] = 26873,
	[11825] = 15628,
	[12682] = 16642,
	[12684] = 16644,
	[23155] = 28953,
	[21277] = 26011,
	[65411] = 88012,
	[52495] = 73626,
	[52377] = 73271,
	[65410] = 88035,
	[65414] = 88045,
	[12704] = 16662,
	[65418] = 88021,
	[65426] = 88003,
	[12833] = 16988,
	[65432] = 88019,
	[23149] = 28944,
	[12713] = 16725,
	[11202] = 13817,
	[52421] = 73373,
	[65407] = 88024,
	[65411] = 88012,
	[65413] = 88037,
	[22537] = 27926,
	[65417] = 88033,
	[52378] = 73272,
	[28273] = 33999,
	[65423] = 88018,
	[29724] = 35559,
	[65429] = 88005,
	[12693] = 16652,
	[22548] = 27962,
	[12694] = 16653,
	[60216] = 84413,
	[52434] = 73465,
	[65412] = 88028,
	[52495] = 73626,
	[52496] = 73627,
	[17706] = 21913,
	[19203] = 23632,
	[52440] = 73471,
	[52377] = 73271,
	[7989] = 9964,
	[52404] = 73355,
	[41779] = 53993,
	[65406] = 88047,
	[12828] = 16984,
	[65410] = 88035,
	[12703] = 16661,
	[52388] = 73280,
	[11611] = 15294,
	[11612] = 15296,
	[18653] = 23078,
	[34173] = 35544,
	[21725] = 26417,
	[21727] = 26420,
	[21729] = 26422,
	[21731] = 26424,
	[21733] = 26426,
	[21735] = 26428,
	[23134] = 34590,
	[19207] = 23637,
	[44917] = 26407,
	[6045] = 7222,
	[24307] = 31450,
	[52462] = 73502,
	[52466] = 73505,
	[52363] = 73224,
	[52494] = 73625,
	[52375] = 73265,
	[18257] = 22732,
	[23593] = 29571,
	[23595] = 29605,
	[12689] = 16648,
	[18650] = 23069,
	[32753] = 41208,
	[31870] = 28948,
	[12827] = 16983,
	[4415] = 3966,
	[27693] = 33289,
	[29219] = 32502,
	[21728] = 26421,
	[21730] = 26423,
	[21732] = 26425,
	[21734] = 26427,
	[52368] = 73245,
	[19208] = 23638,
	[17051] = 20874,
	[19220] = 23667,
	[44919] = 26442,
	[21724] = 26416,
	[23638] = 29728,
	[12691] = 16650,
	[20040] = 24399,
	[18260] = 22750,
	[65419] = 88046,
	[62799] = 88011,
	[19449] = 23804,
	[21726] = 26418,
	[29217] = 32501,
	[65421] = 88039,
	[65422] = 88016,
	[44918] = 26443,
	[65430] = 88014,
	[44916] = 26403,
	[7990] = 9970,
	[65433] = 88044,
	[65427] = 88004,
	[11165] = 13655,
	[27691] = 33287,
	[30444] = 35530,
	[12830] = 57259,
	[23590] = 29566,
	[23592] = 29569,
	[23594] = 29603,
	[23596] = 29606,
	[3870] = 3504,
	[11610] = 15292,
	[20970] = 25610,
	[23591] = 29568,
	[52365] = 73231,
	[17052] = 20876,
	[52382] = 73275,
	[17049] = 20872,
	[17053] = 20873,
	[19206] = 23636,
	[19209] = 23639,
	[17059] = 20890,
	[17060] = 20897,
	[52373] = 73263,
	[17025] = 20855,
	[66119] = 76458,
	[52379] = 73273,
	[24210] = 31103,
	[65424] = 88034,
	[65428] = 88020,
	[7993] = 10005,
	[41561] = 53885,
	[41122] = 54981,
	[11167] = 13687,
	[66108] = 76447,
	[66104] = 76443,
	[17023] = 20854,
	[17022] = 20853,
	[68810] = 89815,
	[4297] = 3771,
	[66109] = 76448,
	[52374] = 73264,
	[15996] = 19793,
	[52383] = 73276,
	[22540] = 27946,
	[41798] = 55397,
	[65425] = 88042,
	[19330] = 23707,
	[23804] = 30317,
	[52390] = 73340,
	[66105] = 76444,
	[52370] = 73258,
	[52387] = 73338,
	[19210] = 23650,
	[19211] = 23652,
	[19212] = 23653,
	[23802] = 30315,
	[41723] = 53996,
	[7975] = 9933,
	[18291] = 22797,
	[12695] = 16654,
	[65416] = 88030,
	[21371] = 26087,
	[3867] = 3495,
	[19205] = 23633,
	[13519] = 17635,
	[23605] = 29619,
	[52372] = 73262,
	[24301] = 31441,
	[65408] = 88017,
	[66103] = 76442,
	[52371] = 73260,
	[66127] = 76467,
	[13519] = 17635,
	[41122] = 54981,
	[66119] = 76458,
	[66127] = 76467,
	[68810] = 89815,
	[17022] = 20853,
	[65415] = 88022,
	[66104] = 76443,
	[52370] = 73258,
	[19330] = 23707,
	[19205] = 23633,
	[19211] = 23652,
	[24301] = 31441,
	[66105] = 76444,
	[66129] = 76469,
	[65408] = 88017,
	[65416] = 88030,
	[3867] = 3495,
	[65424] = 88034,
	[65428] = 88020,
	[24210] = 31103,
	[66122] = 76462,
	[52371] = 73260,
	[52379] = 73273,
	[52383] = 73276,
	[52387] = 73338,
	[41723] = 53996,
	[11167] = 13687,
	[32749] = 41162,
	[15996] = 19793,
	[12695] = 16654,
	[66123] = 76463,
	[12697] = 16656,
	[22220] = 27589,
	[18291] = 22797,
	[17023] = 20854,
	[17025] = 20855,
	[65425] = 88042,
	[66100] = 76439,
	[12837] = 16993,
	[7975] = 9933,
	[66124] = 76464,
	[52372] = 73262,
	[19210] = 23650,
	[21371] = 26087,
	[4297] = 3771,
	[66101] = 76440,
	[66109] = 76448,
	[8409] = 10516,
	[23804] = 30317,
	[9300] = 11477,
	[22540] = 27946,
	[66108] = 76447,
	[66116] = 76455,
	[66103] = 76442,
	[41561] = 53885,
	[18592] = 21161,
	[23605] = 29619,
	[52374] = 73264,
	[67606] = 94732,
	[41798] = 55397,
	[19212] = 23653,
	[66118] = 76457,
	[66126] = 76466,
	[52373] = 73263,
	[66130] = 76470,
	[7993] = 10005,
	[66131] = 76471,
	[66132] = 76472,
	[66117] = 76456,
	[52390] = 73340,
	[66125] = 76465,
	[23802] = 30315,
	[66107] = 76446,
	[66111] = 76450,
	[66115] = 76454,
	[30321] = 36389,
	[12706] = 16664,
	[12707] = 16665,
	[52399] = 73350,
	[52401] = 73352,
	[35708] = 46803,
	[66120] = 76459,
	[66128] = 76468,
	[12714] = 16726,
	[52417] = 73369,
	[22214] = 27588,
	[52423] = 73375,
	[52435] = 73466,
	[52437] = 73468,
	[52376] = 73269,
	[66121] = 76461,
	[52380] = 73336,
	[52384] = 73337,
	[71933] = 101789,
	[52398] = 73349,
	[66106] = 76445,
	[66110] = 76449,
	[52414] = 73366,
	[4298] = 3775,
	[71938] = 101794,
	[52436] = 73467,
	[12719] = 16732,
	[68782] = 96256,
	[52420] = 73372,
	[52430] = 73382,
	[69820] = 73266,
	[52386] = 73278,
	[65359] = 92370,
}

-- Items that should not be handled by RecipeKnown
db.BadItems = {
	22200,			-- Silvershafted Arrow
	27736,			-- Master Cookbook
	37460,			-- Rope Pet Leash
	45912,			-- Book of Glyph Mastery
	46809,			-- Bountiful Cookbook (Alliance)
	46810,			-- Bountiful Cookbook (Horde)
	89139,			-- Chain Pet Leash
	89640,			-- Life Spirit
	89641,			-- Water Spirit
}

db.ClassBooks = {
	-- Druid Books (Book of)
	17682,			-- Gift of the Wild
	17683,			-- Gift of the Wild 2
	22146,			-- Gift of the Wild 3
	21294,			-- Healing Touch 11
	21295,			-- Starfire 7
	21296,			-- Rejuvenation 11
	24345,			-- Cower 4
	-- Mage Books (Tome of)
	18600,			-- Arcane Brilliance
	22153,			-- Arcane Brilliance 2
	21214,			-- Frostbolt 11
	21279,			-- Fireball 12
	21280,			-- Arcane Missles 8
	22739,			-- Polymorph: Turtle
	22890, 			-- Frost Ward 5
	22897,			-- Conjure Food 7
	31501,			-- Conjure Food 8
	29550, 			-- Conjure Water 9
	44602,			-- Dalaran Intellect
	44709,			-- Polymorph: Black Cat
	44714,			-- Dalaran Brilliance
	-- Priest Books (Codex:)
	17413,			-- Prayer of Fortitude
	17414, 			-- Prayer of Fortitude 2
	29549,			-- Prayer of Fortitude 3
	21284,			-- Greater Heal 5
	21285,			-- Renew 10
	21287,			-- Prayer of Healing 5
	22393,			-- Prayer of Shadow Protection
	31837,			-- Prayer of Shadow Protection 2
	-- Rogue Books (Handbook of)
	21300,			-- Backstab 9
	21302, 			-- Deadly Poison 5
	21303,			-- Feint 5
	-- Shaman (Tablet of)
	23320,			-- Flame Shock 6
	21291,			-- Healing Wave 10
	21292, 			-- Strength of Earth Totem 5
	21293,			-- Grace of Air Totem 3
	-- Warlock Books (Grimoire of)
	4213,				-- Doom (BoP) Added for later Loot support
	9214,				-- Inferno (BoP) Added for later Loot support
	21281,			-- Shadow Bolt 10
	21282,			-- Immolate 8
	21283,			-- Corruption 7
	22891, 			-- Shadow Ward 4
}

db.MountItems = {
	-- Item ID = Mount Spell ID

	-- Mounts
	[1132] = 580,				-- Timber Wolf (Horde)
	[1133] = 581,				-- Winter Wolf
	[1134] = 459,				-- Gray Wolf (Horde)
	[2411] = 470,				-- Black Stallion (Alliance)
	[2413] = 471,				-- Palamino
	[2414] = 472,				-- Pinto (Alliance)
	[2415] = 468,				-- White Stallion
	[5655] = 6648,				-- Chestnut Mare (Alliance)
	[5656] = 458,				-- Brown Horse (Alliance)
	[5665] = 6653,				-- Dire Wolf (Horde)
	[5668] = 6654,				-- Brown Wolf (Horde)
	[5864] = 6777,				-- Gray Ram (Alliance)
	[5872] = 6899,				-- Brown Ram (Alliance)
	[5873] = 6898,				-- White Ram (Alliance)
	[5874] = 6896,				-- Black Ram
	[5875] = 6897,				-- Blue Ram
	[8563] = 10873,			-- Red Mechanostrider (Alliance)
	[8586] = 16084,			-- Mottled Red Raptor (Horde)
	[8588] = 8395,				-- Emerald Raptor (Horde)
	[8591] = 10796,			-- Turquoise Raptor (Horde)
	[8592] = 10799,			-- Violet Raptor (Horde)
	[8595] = 10969,			-- Blue Mechanostrider (Alliance)
	[8629] = 10793,			-- Striped Nightsaber (Alliance)
	[8630] = 10790,			-- Tiger
	[8631] = 8394,				-- Striped Frostsaber (Alliance)
	[8632] = 10789,			-- Spotted Frostsaber (Alliance)
	[8633] = 10788,			-- Leopard
	[12302] = 16056,		-- Ancient Frostsaber (Alliance)
	[12303] = 16055,		-- Black Nightsaber (Alliance)
	[12325] = 16058,		-- Primal Leopard (Alliance)
	[12326] = 16059,		-- Tawny Sabercat (Alliance)
	[12327] = 16060,		-- Golden Sabercat (Alliance)
	[12330] = 16080,		-- Red Wolf (Horde)
	[12351] = 16081,		-- Winter Wolf (Horde)
	[12353] = 16083,		-- White Stallion (Alliance)
	[12354] = 16082,		-- Palomino (Alliance)
	[13086] = 17229,		-- Winterspring Frostsaber (Alliance)
	[13317] = 17450,		-- Ivory Raptor (Horde)
	[13321] = 17453,		-- Green Mechanostrider (Alliance)
	[13322] = 17454,		-- Unpainted Mechanostrider (Alliance)
	[13323] = 17455,		-- Purple Mechanostrider (Alliance)
	[13324] = 17456,		-- Red and Blue Mechanostrider (Alliance)
	[13325] = 17458,		-- Fluorescent Green Mechanostrider (Alliance)
	[13326] = 15779,		-- White Mechanostrider Mod B (Alliance)
	[13327] = 17459,		-- Icy Blue Mechanostrider Mod A (Alliance)
	[13328] = 17461,		-- Black Ram (Alliance)
	[13329] = 17460,		-- Frost Ram (Alliance)
	[13331] = 17462,		-- Red Skeletal Horse (Horde)
	[13332] = 17463,		-- Blue Skeletal Horse (Horde)
	[13333] = 17464,		-- Brown Skeletal Horse (Horde)
	[13334] = 17465,		-- Green Skeletal Warhorse (Horde)
	[13335] = 17481,		-- Rivendare's Deathcharger
	[15277] = 18989,		-- Gray Kodo (Horde)
	[15290] = 18990,		-- Brown Kodo (Horde)
	[15292] = 18991,		-- Green Kodo (Horde)
	[15293] = 18992,		-- Teal Kodo (Horde)
	[16338] = 458,				-- Brown Horse
	[16343] = 6654,			-- Brown Wolf
	[18766] = 23221,		-- Swift Frostsaber (Alliance)
	[18767] = 23219,		-- Swift Mistsaber (Alliance)
	[18768] = 23220,		-- Swift Dawnsaber (Alliance)
	[18772] = 23225,		-- Swift Green Mechanostrider (Alliance)
	[18773] = 23223,		-- Swift White Mechanostrider (Alliance)
	[18774] = 23222,		-- Swift Yellow Mechanostrider (Alliance)
	[18776] = 23227,		-- Swift Palomino (Alliance)
	[18777] = 23229,		-- Swift Brown Steed (Alliance)
	[18778] = 23228,		-- Swift White Steed (Alliance)
	[18785] = 23240,		-- Swift White Ram (Alliance)
	[18786] = 23238,		-- Swift Brown Ram (Alliance)
	[18787] = 23239,		-- Swift Gray Ram (Alliance)
	[18788] = 23241,		-- Swift Blue Raptor (Horde)
	[18789] = 23242,		-- Swift Olive Raptor (Horde)
	[18790] = 23243,		-- Swift Orange Raptor (Horde)
	[18791] = 23246,		-- Purple Skeletal Warhorse (Horde)
	[18793] = 23247,		-- Great White Kodo (Horde)
	[18794] = 23249,		-- Great Brown Kodo (Horde)
	[18795] = 23248,		-- Great Gray Kodo (Horde)
	[18796] = 23250,		-- Swift Brown Wolf (Horde)
	[18797] = 23251,		-- Swift Timber Wolf (Horde)
	[18798] = 23252,		-- Swift Gray Wolf (Horde)
	[18902] = 23338,		-- Swift Stormsaber (Alliance)
	[19029] = 23509,		-- Frostwolf Howler (Horde)
	[19030] = 23510,		-- Stormpike Battle Charger (Alliance)
	[19872] = 24242,		-- Swift Razzashi Raptor
	[19902] = 24252,		-- Swift Zulian Tiger
	[21176] = 26656,		-- Black Qiraji Battle Tank
	[21218] = 25953,		-- Blue Qiraji Battle Tank
	[21321] = 26054,		-- Red Qiraji Battle Tank
	[21323] = 26056,		-- Green Qiraji Battle Tank
	[21324] = 26055,		-- Yellow Qiraji Battle Tank
	[21736] = 3363,			-- Nether Drake
	[23193] = 29059,		-- Naxxramas Deathcharger
	[23720] = 30174,		-- Riding Turtle
	[25596] = 32345,		-- Peep the Phoenix Mount
	[25664] = 32420,		-- Old Crappy McWeakSauce
	[28481] = 34406,		-- Brown Elekk (Alliance)
	[28482] = 34407,		-- Great Elite Elekk (Alliance)
	[28915] = 39316,		-- Dark Riding Talbuk
	[28927] = 34795,		-- Red Hawkstrider (Horde)
	[28936] = 33660,		-- Swift Pink Hawkstrider (Horde)
	[29102] = 34896,		-- Cobalt War Talbuk (Horde)
	[29103] = 34897,		-- White War Talbuk (Horde)
	[29104] = 34898,		-- Silver War Talbuk (Horde)
	[29105] = 34899,		-- Tan War Talbuk (Horde)
	[29220] = 35020,		-- Blue Hawkstrider (Horde)
	[29221] = 35022,		-- Black Hawkstrider (Horde)
	[29222] = 35018,		-- Purple Hawkstrider (Horde)
	[29223] = 35025,		-- Swift Green Hawkstrider (Horde)
	[29224] = 35027,		-- Swift Purple Hawkstrider (Horde)
	[29227] = 34896,		-- Cobalt War Talbuk (Alliance)
	[29228] = 34790,		-- Dark War Talbuk
	[29229] = 34898,		-- Silver War Talbuk (Alliance)
	[29230] = 34899,		-- Tan War Talbuk (Alliance)
	[29231] = 34897,		-- White War Talbuk (Alliance)
	[29465] = 22719,		-- Black Battlestrider (Alliance)
	[29466] = 22718,		-- Black War Kodo (Horde)
	[29467] = 22720,		-- Black War Ram (Alliance)
	[29468] = 22717,		-- Black War Steed (Alliance)
	[29469] = 22724,		-- Black War Wolf (Horde)
	[29470] = 22722,		-- Red Skeletal Warhorse (Horde)
	[29471] = 22723,		-- Black War Tiger (Alliance)
	[29472] = 22721,		-- Black War Raptor (Horde)
	[29743] = 35711,		-- Purple Elekk (Alliance)
	[29744] = 35710,		-- Gray Elekk (Alliance)
	[29745] = 35713,		-- Great Blue Elekk (Alliance)
	[29746] = 35712,		-- Great Green Elekk (Alliance)
	[29747] = 35714,		-- Great Purple Elekk (Alliance)
	[30480] = 36702,		-- Fiery Warhorse
	[31829] = 39315,		-- Cobalt Riding Talbuk (Horde)
	[31830] = 39315,		-- Cobalt Riding Talbuk (Alliance)
	[31831] = 39317,		-- Silver Riding Talbuk (Horde)
	[31832] = 39317,		-- Silver Riding Talbuk (Alliance)
	[31833] = 39318,		-- Tan Riding Talbuk (Horde)
	[31834] = 39318,		-- Tan Riding Talbuk (Alliance)
	[31835] = 39319,		-- White Riding Talbuk (Horde)
	[31836] = 39319,		-- White Riding Talbuk (Alliance)
	[32768] = 41252,		-- Raven Lord
	[33809] = 43688,		-- Amani War Bear
	[33976] = 43899,		-- Brewfest Ram
	[33977] = 43900,		-- Swift Brewfest Ram
	[34060] = 44153,		-- Flying Machine
	[34061] = 44151,		-- Turbo-Charged Flying Machine
	[34129] = 35028,		-- Swift Warstrider (Horde)
	[35513] = 46628,		-- Swift White Hawkstrider
	[35906] = 48027,		-- Black War Elekk (Alliance)
	[37012] = 48025,		-- Headless Horseman's Mount
	[37719] = 49322,		-- Swift Zhevra
	[37828] = 49379,		-- Great Brewfest Kodo
	[43599] = 58983,		-- Big Blizzard Bear
	[43956] = 59785,		-- Black War Mammoth (Alliance)
	[43958] = 59799,		-- Ice Mammoth (Alliance)
	[43959] = 61465,		-- Grand Black War Mammoth (Alliance)
	[43961] = 61470,		-- Grand Ice Mammoth (Alliance)
	[43962] = 54753,		-- White Polar Bear
	[43963] = 59573,		-- Brown Polar Bear
	[43964] = 59572,		-- Black Polar Bear
	[44077] = 59788,		-- Black War Mammoth (Horde)
	[44080] = 59797,		-- Ice Mammoth (Horde)
	[44083] = 61467,		-- Grand Black War Mammoth (Horde)
	[44086] = 61469,		-- Grand Ice Mammoth (Horde)
	[44223] = 60118,		-- Black War Bear (Alliance)
	[44224] = 60119,		-- Black War Bear (Horde)
	[44225] = 60114,		-- Armored Brown Bear (Alliance)
	[44226] = 60116,		-- Armored Brown Bear (Horde)
	[44230] = 59791,		-- Wooly Mammoth (Alliance)
	[44231] = 59793,		-- Wooly Mammoth (Horde)
	[44234] = 61447,		-- Traveler's Tundra Mammoth (Horde)
	[44235] = 61425,		-- Traveler's Tundra Mammoth (Alliance)
	[44554] = 61451,		-- Flying Carpet
	[44558] = 61309,		-- Magnificent Flying Carpet
	[45125] = 63232,		-- Stormwind Steed (Alliance)
	[45586] = 63636,		-- Ironforge Ram (Alliance)
	[45589] = 63638,		-- Gnomeregan Mechanostrider (Alliance)
	[45590] = 63639,		-- Exodar Elekk (Alliance)
	[45591] = 63637,		-- Darnassian Nightsaber (Alliance)
	[45592] = 63641,		-- Thunder Bluff Kodo (Horde)
	[45593] = 63635,		-- Darkspear Raptor (Horde)
	[45595] = 63640,		-- Orgrimmar Wolf (Horde)
	[45596] = 63642,		-- Silvermoon Hawkstrider (Horde)
	[45597] = 63643,		-- Forsaken Warhorse (Horde)
	[46099] = 64658,		-- Black Wolf (Horde)
	[46100] = 64657,		-- White Kodo (Horde)
	[46101] = 64656,		-- Blue Skeletal Warhorse (Horde)
	[46102] = 64659,		-- Venomhide Ravasaur (Horde)
	[46109] = 64731,		-- Sea Turtle
	[46308] = 64977,		-- Black Skeletal Horse (Horde)
	[46743] = 65644,		-- Swift Purple Raptor (Horde)
	[46744] = 65638,		-- Swift Moonsaber (Alliance)
	[46745] = 65637,		-- Great Red Elekk (Alliance)
	[46746] = 65645,		-- White Skeletal Warhorse (Horde)
	[46747] = 65642,		-- Turbostrider (Alliance)
	[46748] = 65643,		-- Swift Violet Ram (Alliance)
	[46749] = 65646,		-- Swift Burgundy Wolf (Horde)
	[46750] = 65641,		-- Great Golden Kodo (Horde)
	[46751] = 65639,		-- Swift Red Hawkstrider (Horde)
	[46752] = 65640,		-- Swift Gray Steed (Alliance)
	[46815] = 66090,		-- Quel'dorei Steed (Alliance)
	[46816] = 66091,		-- Sunreaver Hawkstrider (Horde)
	[47100] = 66847,		-- Striped Dawnsaber (Alliance)
	[47101] = 66846,		-- Ochre Skeletal Warhorse (Horde)
	[47179] = 66906,		-- Argent Charger
	[47180] = 67466,		-- Argent Warhorse
	[49044] = 68057,		-- Swift Alliance Steed (Alliance)
	[49046] = 68056,		-- Swift Horde Wolf (Horde)
	[49096] = 68187,		-- Crusader's White Warhorse (Alliance)
	[49098] = 68188,		-- Crusader's Black Warhorse (Horde)
	[49282] = 51412,		-- Big Battle Bear
	[49283] = 42776,		-- Spectral Tiger
	[49284] = 42777,		-- Swift Spectral Tiger
	[49290] = 65917,		-- Magic Rooster
	[50250] = 71342,		-- Big Love Rocket
	[50420] = 10799,		-- Violet Raptor (Horde)
	[50818] = 72286,		-- Invincible
	[52200] = 73313,		-- Crimson Deathcharger
	[54068] = 74918,		-- Wooly White Rhino
	[54797] = 75596,		-- Frosty Flying Carpet
	[54811] = 75614,		-- Celestial Steed
	[60954] = 84751,		-- Fossilized Raptor
	[62298] = 90621,		-- Golden King (Alliance)
	[62461] = 87090,		-- Goblin Trike (Horde)
	[62462] = 87091,		-- Goblin Turbo-Trike (Horde)
	[63044] = 88748,		-- Brown Riding Camel
	[63045] = 88749,		-- Tan Riding Camel
	[63046] = 88750,		-- Grey Riding Camel
	[64883] = 92155,		-- Ultramarine Qiraji Battle Tank
	[67107] = 93644,		-- Kor'kron Annihilator (Horde)
	[68823] = 96491,		-- 
	[68824] = 96499,		-- 
	[68825] = 96503,		-- 
	[69213] = 97359,		-- 
	[69224] = 97493,		-- 
	[69226] = 97501,		-- 
	[69228] = 97581,		-- 

	-- Flying Mounts
	[25470] = 32235,		-- Golden Gryphon (Alliance)
	[25471] = 32239,		-- Ebon Gryphon (Alliance)
	[25472] = 32240,		-- Snowy Gryphon (Alliance)
	[25473] = 32242,		-- Swift Blue Gryphon (Alliance)
	[25474] = 32243,		-- Tawny Wind Rider (Horde)
	[25475] = 32244,		-- Blue Wind Rider (Horde)
	[25476] = 32245,		-- Green Wind Rider (Horde)
	[25477] = 32246,		-- Swift Red Wind Rider (Horde)
	[25527] = 32289,		-- Swift Red Gryphon (Alliance)
	[25528] = 32290,		-- Swift Green Gryphon (Alliance)
	[25529] = 32292,		-- Swift Purple Gryphon (Alliance)
	[25531] = 32295,		-- Swift Green Wind Rider (Horde)
	[25532] = 32296,		-- Swift Yellow Wind Rider (Horde)
	[25533] = 32297,		-- Swift Purple Wind Rider (Horde)
	[30609] = 37015,		-- Swift Nether Drake
	[32314] = 39798,		-- Green Riding Nether Ray
	[32316] = 39801,		-- Purple Riding Nether Ray
	[32317] = 39800,		-- Red Riding Nether Ray
	[32318] = 39802,		-- Silver Riding Nether Ray
	[32319] = 39803,		-- Blue Riding Nether Ray
	[32458] = 40192,		-- Ashes of Al'ar
	[32857] = 41513,		-- Onyx Netherwing Drake
	[32858] = 41514,		-- Azure Netherwing Drake
	[32859] = 41515,		-- Cobalt Netherwing Drake
	[32860] = 41516,		-- Purple Netherwing Drake
	[32861] = 41517,		-- Veridian Netherwing Drake
	[32862] = 41518,		-- Violet Netherwing Drake
	[33999] = 43927,		-- Cenarion War Hippogryph
	[34092] = 44744,		-- Merciless Nether Drake
	[37676] = 49193,		-- Vengeful Nether Drake
	[38690] = 51960,		-- Frost Wyrm Mount
	[40775] = 54729,		-- Winged Steed of the Ebon Blade
	[43516] = 58615,		-- Brutal Nether Drake
	[43951] = 59569,		-- Bronze Drake
	[43952] = 59567,		-- Azure Drake
	[43953] = 59568,		-- Blue Drake
	[43954] = 59571,		-- Twilight Drake
	[43955] = 59570,		-- Red Drake
	[43986] = 59650,		-- Black Drake
	[44151] = 59996,		-- Blue Proto-Drake
	[44160] = 59961,		-- Red Proto-Drake
	[44164] = 59976,		-- Black Proto-Drake
	[44168] = 60002,		-- Time-Lost Proto-Drake
	[44175] = 60021,		-- Plagued Proto-Drake
	[44177] = 60024,		-- Violet Proto-Drake
	[44178] = 60025,		-- Albino Drake
	[44689] = 61229,		-- Armored Snowy Gryphon (Alliance)
	[44690] = 61230,		-- Armored Blue Wind Rider (Horde)
	[44707] = 61294,		-- Green Proto-Drake
	[44842] = 61997,		-- Red Dragonhawk (Horde)
	[44843] = 61996,		-- Blue Dragonhawk (Alliance)
	[44857] = 62048,		-- Black Dragonhawk Mount
	[45693] = 63796,		-- Mimiron's Head
	[45725] = 63844,		-- Argent Hippogryph
	[45801] = 63956,		-- Ironbound Proto-Drake
	[45802] = 63963,		-- Rusted Proto-Drake
	[46171] = 65439,		-- Furious Gladiator's Frost Wyrm
	[46708] = 64927,		-- Deadly Gladiator's Frost Wyrm
	[46813] = 66087,		-- Silver Covenant Hippogryph (Alliance)
	[46814] = 66088,		-- Sunreaver Dragonhawk (Horde)
	[47840] = 67336,		-- Relentless Gladiator's Frost Wyrm
	[49285] = 46197,		-- X-51 Nether-Rocket
	[49286] = 46199,		-- X-51 Nether-Rocket X-TREME
	[49636] = 69395,		-- Onyxian Drake
	[50435] = 71810,		-- Wrathful Gladiator's Frost Wyrm
	[51954] = 72808,		-- Bloodbathed Frostbrood Vanquisher
	[51955] = 72807,		-- Icebound Frostbrood Vanquisher
	[54069] = 74856,		-- Blazing Hippogryph
	[54860] = 75973,		-- X-53 Touring Rocket
	[62900] = 88331,		-- Volcanic Stone Drake
	[62901] = 88335,		-- Drake of the East Wind
	[63039] = 88741,		-- Drake of the West Wind (Alliance)
	[63040] = 88742,		-- Drake of the North Wind
	[63041] = 88744,		-- Drake of the South Wind
	[63042] = 88718,		-- Phosphorescent Stone Drake
	[63043] = 88746,		-- Vitreous Stone Drake
	[63125] = 88990,		-- Dark Phoenix
	[64998] = 92231,		-- Spectral Steed (Alliance)
	[64999] = 92232,		-- Spectral Wolf (Horde)
	[65356] = 88741,		-- Drake of the West Wind (Horde)
	[68008] = 93623,		-- Mottled Drake
}

db.Companions = {
	-- Item ID = Spell ID
	
	[4401] = 4055,			-- Mechanical Squirrel
	[8485] = 10673,			-- Bombay Cat
	[8486] = 10674,			-- Cornish Rex Cat
	[8487] = 10676,			-- Orange Tabby Cat
	[8488] = 10678,			-- Silver Tabby Cat
	[8489] = 10679,			-- White Kitten
	[8490] = 10677,			-- Siamese Cat
	[8491] = 10675,			-- Black Tabby Cat
	[8492] = 10683,			-- Green Wing Macaw
	[8494] = 10682,			-- Hyacinth Macaw
	[8495] = 10684,			-- Senegal
	[8496] = 10680,			-- Cockatiel
	[8497] = 10711,			-- Snowshoe Rabbit
	[8498] = 10698,			-- Emerald Whelpling
	[8499] = 10697,			-- Crimson Whelpling
	[8500] = 10707,			-- Great Horned Owl
	[8501] = 10706,			-- Hawk Owl
	[10360] = 10714,		-- Black Kingsnake
	[10361] = 10716,		-- Brown Snake
	[10392] = 10717,		-- Crimson Snake
	[10393] = 10688,		-- Cockroach
	[10394] = 10709,		-- Brown Prairie Dog
	[10398] = 12243,		-- Mechanical Chicken
	[10822] = 10695,		-- Dark Whelpling
	[11023] = 10685,		-- Ancona Chicken
	[11026] = 10704,		-- Tree Frog
	[11027] = 10703,		-- Wood Frog
	[11110] = 13548,		-- Westfall Chicken
	[11474] = 15067,		-- Sprite Darter Hatchling
	[11825] = 15048,		-- Pet Bombling
	[11826] = 15049,		-- Lil' Smoky
	[11903] = 15648,		-- Corrupted Kitten
	[12264] = 15999,		-- Worg Pup
	[12529] = 16450,		-- Smolderweb Hatchling
	[13582] = 17709,		-- Zergling
	[13583] = 17707,		-- Panda Cub
	[13584] = 17708,		-- Mini Diablo
	[15996] = 19772,		-- Lifelike Toad
	[18963] = 23428,		-- Albino Snapjaw
	[18964] = 23429,		-- Loggerhead Snapjaw
	[18965] = 23432,		-- Hawksbill Snapjaw
	[18966] = 23431,		-- Leatherback Snapjaw
	[18967] = 23430,		-- Olive Snapjaw
	[19054] = 23530,		-- Tiny Red Dragon
	[19055] = 23531,		-- Tiny Green Dragon
	[19450] = 23811,		-- Jubling
	[20371] = 24696,		-- Murky
	[20651] = 25018,		-- Murki
	[20769] = 25162,		-- Disgusting Oozeling
	[21168] = 25849,		-- Baby Shark
	[21277] = 26010,		-- Tranquil Mechanical Yeti
	[21301] = 26533,		-- Father Winter's Helper
	[21305] = 26541,		-- Winter's Little Helper
	[21308] = 26529,		-- Winter Reindeer
	[21309] = 26045,		-- Tiny Snowman
	[22114] = 27241,		-- Gurky
	[22235] = 27570,		-- Peddlefeet
	[22780] = 28487,		-- Terky
	[22781] = 28505,		-- Poley
	[23002] = 28738,		-- Speedy
	[23007] = 28739,		-- Mr. Wiggles
	[23015] = 28740,		-- Whiskers the Rat
	[23083] = 28871,		-- Spirit of Summer
	[23712] = 30152,		-- White Tiger Cub
	[23713] = 30156,		-- Hippogryph Hatchling
	[25535] = 32298,		-- Netherwhelp
	[27445] = 33050,		-- Magical Crawdad
	[29363] = 35156,		-- Mana Wyrmling
	[29364] = 35239,		-- Brown Rabbit
	[29901] = 35907,		-- Blue Moth
	[29902] = 35909,		-- Red Moth
	[29903] = 35910,		-- Yellow Moth
	[29904] = 35911,		-- White Moth
	[29953] = 36027,		-- Golden Dragonhawk Hatchling
	[29956] = 36028,		-- Red Dragonhawk Hatchling
	[29957] = 36029,		-- Silver Dragonhawk Hatchling
	[29958] = 36031,		-- Blue Dragonhawk Hatchling
	[29960] = 36034,		-- Firefly
	[30360] = 24988,		-- Lurky
	[31760] = 39181,		-- Miniwing
	[32233] = 39709,		-- Wolpertinger
	[32465] = 40319,		-- Lucky
	[32498] = 40405,		-- Lucky
	[32588] = 40549,		-- Banana Charm				-- Bananas
	[32616] = 40614,		-- Egbert
	[32617] = 40613,		-- Willy
	[32622] = 40634,		-- Peanut
	[33154] = 42609,		-- Sinister Squashling
	[33816] = 43697,		-- Toothy
	[33818] = 43698,		-- Muckbreath
	[33993] = 43918,		-- Mojo
	[34425] = 54187,		-- Clockwork Rocket Bot
	[34478] = 45082,		-- Tiny Sporebat
	[34492] = 45125,		-- Rocket Chicken
	[34493] = 45127,		-- Dragon Kite
	[34518] = 45174,		-- Golden Pig
	[34519] = 45175,		-- Silver Pig
	[34535] = 10696,		-- Azure Whelpling
	[34955] = 45890,		-- Searing Scorchling
	[35349] = 46425,		-- Snarly
	[35350] = 46426,		-- Chuck
	[35504] = 46599,		-- Phoenix Hatchling
	[37297] = 48406,		-- Spirit of Competition
	[37298] = 48408,		-- Essence of Competition
	[38050] = 49964,		-- Soul-Trader Beacon		-- Ethereal Soul-Trader
	[38628] = 51716,		-- Nether Ray Fry
	[38658] = 51851,		-- Vampiric Batling
	[39286] = 52615,		-- Frosty
	[39656] = 53082,		-- Mini Tyrael
	[39898] = 61351,		-- Cobra Hatchling
	[39899] = 61349,		-- White Tickbird Hatchling
	[39973] = 53316,		-- Ghostly Skull
	[40653] = 40990,		-- Reeking Pet Carrier		-- Stinker
	[41133] = 55068,		-- Unhatched Mr. Chilly 	-- Mr. Chilly
	[43698] = 59250,		-- Giant Sewer Rat
	[44721] = 61350,		-- Proto-Drake Whelp
	[44723] = 61357,		-- Nurtured Penguin Egg		-- Pengu
	[44738] = 61472,		-- Kirin Tor Familiar
	[44794] = 61725,		-- Spring Rabbit's Foot		-- Spring Rabbit
	[44810] = 61773,		-- Turkey Cage				-- Plump Turkey
	[44819] = 61855,		-- Baby Blizzard Bear
	[44822] = 10713,		-- Albino Snake
	[44841] = 61991,		-- Little Fawn's Salt Lick	-- Little Fawn
	[44965] = 62491,		-- Teldrassil Sproutling
	[44970] = 62508,		-- Dun Morogh Cub
	[44971] = 62510,		-- Tirisfal Batling
	[44973] = 62513,		-- Durotar Scorpion
	[44974] = 62516,		-- Elwynn Lamb
	[44980] = 62542,		-- Mulgore Hatchling
	[44982] = 62564,		-- Enchanted Broom
	[44983] = 62561,		-- Strand Crawler
	[44984] = 62562,		-- Ammen Vale Lashling
	[44998] = 62609,		-- Argent Squire (Alliance)
	[45002] = 62674,		-- Mechanopeep
	[45022] = 62746,		-- Argent Gruntling (Horde)
	[45180] = 63318,		-- Murkimus' Little Spear	-- Murkimus the Gladiator
	[45606] = 63712,		-- Sen'jin Fetish
	[45942] = 64351,		-- XS-001 Constructor Bot
	[46325] = 65046,		-- Withers
	[46398] = 65358,		-- Cat Carrier (Calico Cat)	-- Calico Cat
	[46544] = 65382,		-- Curious Wolvar Pup
	[46545] = 65381,		-- Curious Oracle Hatchling
	[46707] = 44369,		-- Pint-Sized Pink Pachyderm
	[46767] = 65682,		-- Warbot Ignition Key		-- Warbot
	[46802] = 66030,		-- Heavy Murloc Egg			-- Grunty
	[46820] = 66096,		-- Shimmering Wyrmling (Alliance)
	[46821] = 66096,		-- Shimmering Wyrmling (Horde)
	[46892] = 63318,		-- Murkimus' Tiny Spear		-- Murkimus the Gladiator
	[46894] = 66520,		-- Jade Tiger
	[48112] = 67413,		-- Darting Hatchling
	[48114] = 67414,		-- Deviate Hatchling
	[48116] = 67415,		-- Gundrak Hatchling
	[48118] = 67416,		-- Leaping Hatchling
	[48120] = 67417,		-- Obsidian Hatchling
	[48122] = 67418,		-- Ravasaur Hatchling
	[48124] = 67419,		-- Razormaw Hatchling
	[48126] = 67420,		-- Razzashi Hatchling
	[48527] = 67527,		-- Enchanted Onyx			-- Onyx Panther
	[49287] = 68767,		-- Tuskarr Kite
	[49343] = 68810,		-- Spectral Tiger Cub
	[49362] = 69002,		-- Onyxian Whelpling
	[49646] = 69452,		-- Core Hound Pup
	[49662] = 69535,		-- Gryphon Hatchling
	[49663] = 69536,		-- Wind Rider Cub
	[49664] = 69539,		-- Enchanted Purple Jade	-- Zipao Tiger
	[49665] = 69541,		-- Pandaren Monk
	[49693] = 69677,		-- Lil' Phylactery			-- Lil' K.T.
	[49912] = 70613,		-- Perky Pug
	[50446] = 71840,		-- Toxic Wasteling
	[53641] = 74932,		-- Ice Chip					-- Frigid Frostling
	[54436] = 75134,		-- Blue Clockwork Rocket Bot
	[54810] = 75613,		-- Celestial Dragon
	[54847] = 75906,		-- Lil' XT
	[54857] = 75936,		-- Murkimus the Gladiator
	[56806] = 78381,		-- Mini Thor
	[59597] = 81937,		-- Personal World Destroyer
	[60216] = 82173,		-- De-Weaponized Mechanical Companion
	[60847] = 84263,		-- Crawling Claw
	[60869] = 84492,		-- Pebble
	[60955] = 84752,		-- Fossilized Hatchling
	[62540] = 87344,		-- Lil' Deathwing
	[62769] = 87863,		-- Hardboiled Egg			-- Eat the Egg
	[63138] = 89039,		-- Dark Phoenix Hatchling
	[63355] = 89472,		-- Rustberg Seagull (Alliance)
	[63398] = 89670,		-- Armadillo Pup
	[64372] = 90523,		-- Clockwork Gnome
	[64403] = 90637,		-- Fox Kit
	[64494] = 91343,		-- Tiny Shale Spider
	[64996] = 89472,		-- Rustberg Seagull (Horde)
	[65361] = 92395,		-- Guild Page (Alliance)
	[65362] = 92396,		-- Guild Page (Horde)
	[65363] = 92397,		-- Guild Herald (Alliance)
	[65364] = 92398,		-- Guild Herald (Horde)
	[65661] = 78683,		-- Blue Mini Jouster
	[65662] = 78685,		-- Gold Mini Jouster
	[66067] = 93823,		-- Brazie's Sunflower Seeds	-- Brazie's Sunflower
	[66070] = 93818,		-- Lizzy
	[66073] = 93817,		-- Little Snail
	[66075] = 93815,		-- Bubbles
	[66076] = 93739,		-- Mr. Grubbs
	[66080] = 93813,		-- Tiny Flamefly
	[67128] = 93624,		-- Landro's Lil' XT
	[67274] = 93836,		-- Enchanted Lantern
	[67275] = 93837,		-- Magic Lamp
	[67282] = 93838,		-- Elementium Geode
	[67418] = 94070,		-- Smoldering Murloc Egg	-- Deathy
	[67600] = 94716,		-- Lil' Alexstrasza
	[68385] = 95787,		-- Lil' Ragnaros
	[68618] = 95786,		-- Moonkin Hatchling (Alliance)
	[68619] = 95909,		-- Moonkin Hatchling (Horde)
	[68673] = 16450,		-- Smolderweb Hatchling
	[68833] = 96571,		-- Panther Cub
	[68840] = 96817,		-- Landro's Lichling
	[68841] = 96819,		-- Nightsaber Cub
	[69239] = 97638,		-- Winterspring Cub
	[69251] = 97779,		-- Lashtail Hatchling
	[69648] = 98079,		-- Legs
	[69821] = 98571,		-- Pterrordax Hatchling
	[69824] = 98587,		-- Voodoo Figurine
	[69847] = 98736,		-- Guardian Cub
	[69991] = 45082,		-- Tiny Sporebat
	[69992] = 66096,		-- Shimmering Wyrmling
	[70099] = 23713,		-- Cenarion Hatchling		-- Hippogryph Hatchling
	[70140] = 99663,		-- Hyjal Bear Cub
	[70160] = 99668,		-- Crimson Lasher
	[70908] = 100330,		-- Feline Familiar
	[71033]	= 100576,		-- Lil' Tarecgosa
	[71076] = 100684,		-- Creepy Crate
	[71140] = 100970,		-- Nuts' Acorn				-- Nuts
	[71387] = 101424,		-- Brilliant Kaliri
	[71624] = 101493,		-- Purple Puffer
	[71726] = 101606,		-- Murky's Little Soulstone	-- Murkablo
	[72042] = 101986,		-- Alliance Balloon
	[72045] = 101989,		-- Horde Balloon
	[72068] = 98736,		-- Guardian Cub
	[72134] = 102317,		-- Grell Moss				-- Gregarious Grell
	[72153] = 102353,		-- Sand Scarab
	[73762] = 103076,		-- Darkmoon Balloon
	[73764] = 101733,		-- Darkmoon Monkey
	[73765] = 103074,		-- Darkmoon Turtle
	[73797] = 103125,		-- Lump of Coal				-- Lumpy
	[73903] = 103544,		-- Darkmoon Tonk
	[73905] = 103549,		-- Darkmoon Zeppelin
	[73953] = 103588,		-- Sea Pony
	[74610] = 104047,		-- Lunar Lantern
	[74611] = 104049,		-- Festival Lantern
	[74981] = 105122,		-- Darkmoon Cub
	[75040] = 103076,		-- Flimsy Darkmoon Balloon
	[75041] = 105228,		-- Flimsy Green Balloon
	[75042] = 105229,		-- Flimsy Yellow Balloon
	[76062] = 105633,		-- Fetish Shaman's Spear	-- Fetish Shaman
	[78916] = 110029,		-- Soul of the Aspects
	[79744] = 112994,		-- Eye of the Legion
	[80008] = 114090,		-- Darkmoon Rabbit
	[82774] = 120501,		-- Jade Owl
	[82775] = 120507,		-- Sapphire Cub
	[84105] = 122748,		-- Fishy
	[85220] = 123778,		-- Terrible Turnip
	[85222] = 123784,		-- Red Cricket
	[85447] = 124000,		-- Tiny Goldfish
	[85513] = 127813,		-- Thundering Serpent Hatchling
	[85578] = 124152,		-- Feral Vermling
	[85871] = 124660,		-- Lucky Quilen Cub
	[86562] = 126247,		-- Hopling
	[86563] = 126249,		-- Hollow Reed
	[86564] = 126251,		-- Imbued Jade Fragment
	[87526] = 126885,		-- Mechanical Pandaren Dragonling
	[87567] = 127006,		-- Food
	[87568] = 127008,		-- Food
	[88147] = 127815,		-- Singing Cricket Cage
	[88148] = 127816,		-- Jade Crane Chick
	[89367] = 127006,		-- Yu'lon Kite
	[89368] = 127008,		-- Chi-ji Kite
	[89587] = 118414,		-- Porcupette
	[89686] = 130726,		-- Jade Tentacle
	[89736] = 130759,		-- Venus
	[90173] = 131590,		-- Pandaren Water Spirit
	[90177] = 131650,		-- Baneling
	[90897] = 90637,		-- Fox Kit
	[90898] = 90637,		-- Fox Kit
	[90900] = 132574,		-- Imperial Moth
	[90902] = 132580,		-- Imperial Silkworm
	[90953] = 132759,		-- Spectral Tiger Cub
	[91003] = 132762,		-- Darkmoon Hatchling
	[91031] = 132785,		-- Darkmoon Glowfly
	[91040] = 132789,		-- Darkmoon Eye
	[92707] = 134538,		-- Cinder Kitten
	[92798] = 134892,		-- Pandaren Fire Spirit
	[92799] = 134894,		-- Pandaren Air Spirit
	[92800] = 134895,		-- Pandaren Earth Spirit
	[93025] = 135156,		-- Clock'em
	[93029] = 135257,		-- Gluth's Bone
	[93030] = 135254,		-- Dusty Clutch of Eggs
	[93031] = 135256,		-- Mr. Bigglesworth
	[93032] = 135255,		-- Blighted Spore
	[93033] = 135258,		-- Mark of Flame
	[93034] = 135259,		-- Blazing Rune
	[93035] = 135261,		-- Core of Hardened Ash
	[93036] = 135263,		-- Unscathed Egg
	[93037] = 135265,		-- Blackwing Banner
	[93038] = 135264,		-- Whistle of Chromatic Bone
	[93039] = 135266,		-- Viscidus Globule
	[93040] = 135267,		-- Anubisath Idol
	[93041] = 135268,		-- Jewel of Maddening Whispers
	
}

--== Derived & Static Values==--

RecipeKnown_Skills = {
	L.SKILL_ALCHEMY,
	L.SKILL_BLACKSMITHING,
	L.SKILL_COOKING,
	L.SKILL_ENCHANTING,
	L.SKILL_ENGINEERING,
	L.SKILL_FIRSTAID,
	L.SKILL_INSCRIPTION,
	L.SKILL_JEWELCRAFTING,
	L.SKILL_LEATHERWORKING,
	L.SKILL_TAILORING,
}

RecipeKnown_Prefixes = {
	L.PREFIX_DESIGN,
	L.PREFIX_FORMULA,
	L.PREFIX_MANUAL,
	L.PREFIX_PLANS,
	L.PREFIX_PATTERN,
	L.PREFIX_RECIPE,
	L.PREFIX_SCHEMATIC,
	L.PREFIX_TECHNIQUE,
}

-- Add Secondary items to the prefixes
-- Currently only used in zhCN translation
if (L.PREFIX_FORMULA2) then
	tinsert(RecipeKnown_Prefixes,L.PREFIX_FORMULA2)
end